Change "Direct Sound" to "DirectSound"
authorRyan Schmidt <git@ryandesign.com>
Sun, 26 Aug 2018 02:29:46 +0000 (21:29 -0500)
committerStephen Sinclair <radarsat1@gmail.com>
Tue, 30 Oct 2018 11:28:16 +0000 (12:28 +0100)
RtAudio.h
contrib/go/rtaudio/rtaudio.go
doc/doxygen/compiling.txt
tests/audioprobe.cpp

index 25c2076b30f4b9aa3c7d116f01e44e641b3f06a6..c83caffee26def8fd20296329c67cfddc0ac2fa5 100644 (file)
--- a/RtAudio.h
+++ b/RtAudio.h
@@ -116,7 +116,7 @@ static const RtAudioFormat RTAUDIO_FLOAT64 = 0x20; // Normalized between plus/mi
     Certain audio APIs offer a number of parameters that influence the
     I/O latency of a stream.  By default, RtAudio will attempt to set
     these parameters internally for robust (glitch-free) performance
-    (though some APIs, like Windows Direct Sound, make this difficult).
+    (though some APIs, like Windows DirectSound, make this difficult).
     By passing the RTAUDIO_MINIMIZE_LATENCY flag to the openStream()
     function, internal stream settings will be influenced in an attempt
     to minimize stream latency, though possibly at the expense of stream
@@ -288,7 +288,7 @@ class RTAUDIO_DLL_PUBLIC RtAudio
     MACOSX_CORE,    /*!< Macintosh OS-X Core Audio API. */
     WINDOWS_WASAPI, /*!< The Microsoft WASAPI API. */
     WINDOWS_ASIO,   /*!< The Steinberg Audio Stream I/O API. */
-    WINDOWS_DS,     /*!< The Microsoft Direct Sound API. */
+    WINDOWS_DS,     /*!< The Microsoft DirectSound API. */
     RTAUDIO_DUMMY,  /*!< A compilable but non-functional API. */
     NUM_APIS        /*!< Number of values in this enum. */
   };
@@ -348,7 +348,7 @@ class RTAUDIO_DLL_PUBLIC RtAudio
     Certain audio APIs offer a number of parameters that influence the
     I/O latency of a stream.  By default, RtAudio will attempt to set
     these parameters internally for robust (glitch-free) performance
-    (though some APIs, like Windows Direct Sound, make this difficult).
+    (though some APIs, like Windows DirectSound, make this difficult).
     By passing the RTAUDIO_MINIMIZE_LATENCY flag to the openStream()
     function, internal stream settings will be influenced in an attempt
     to minimize stream latency, though possibly at the expense of stream
index f487b14d652253a1f5c2f777e760585da1dd46ba..49815a33bb01112cd4039ebde2262fe067a8e454 100644 (file)
@@ -69,7 +69,7 @@ const (
        APIWindowsWASAPI = C.RTAUDIO_API_WINDOWS_WASAPI
        // APIWindowsASIO uses the Steinberg Audio Stream I/O API.
        APIWindowsASIO = C.RTAUDIO_API_WINDOWS_ASIO
// APIWindowsDS uses the Microsoft Direct Sound API.
        APIWindowsDS = C.RTAUDIO_API_WINDOWS_DS
        // APIDummy is a compilable but non-functional API.
        APIDummy = C.RTAUDIO_API_DUMMY
index 819ba9c66d75fec7d1cda96c93c21b3a8551f067..e5c4a9e203e05dbcc940e44ff5079e9e77804065 100644 (file)
@@ -61,7 +61,7 @@ In order to compile RtAudio for a specific OS and audio API, it is necessary to
 </TR>
 <TR>
   <TD>Windows</TD>
-  <TD>Direct Sound</TD>
+  <TD>DirectSound</TD>
   <TD>RtApiDs</TD>
   <TD>__WINDOWS_DS__</TD>
   <TD><TT>dsound.lib (ver. 5.0 or higher), multithreaded</TT></TD>
index c83d3a5f45600cb7bd75895b363e45e0707d813f..f2f47d9ad2f61b62e8989ada090d2606a5e6f266 100644 (file)
@@ -17,7 +17,7 @@ int main()
   std::map<int, std::string> apiMap;
   apiMap[RtAudio::MACOSX_CORE] = "OS-X Core Audio";
   apiMap[RtAudio::WINDOWS_ASIO] = "Windows ASIO";
-  apiMap[RtAudio::WINDOWS_DS] = "Windows Direct Sound";
+  apiMap[RtAudio::WINDOWS_DS] = "Windows DirectSound";
   apiMap[RtAudio::WINDOWS_WASAPI] = "Windows WASAPI";
   apiMap[RtAudio::UNIX_JACK] = "Jack Client";
   apiMap[RtAudio::LINUX_ALSA] = "Linux ALSA";
@@ -69,7 +69,7 @@ const (
        // APIWindowsASIO uses the Steinberg Audio Stream I/O API.
        APIWindowsASIO = C.RTAUDIO_API_WINDOWS_ASIO
-       // APIWindowsDS uses the Microsoft Direct Sound API.
+       // APIWindowsDS uses the Microsoft DirectSound API.
        APIWindowsDS = C.RTAUDIO_API_WINDOWS_DS
        // APIDummy is a compilable but non-functional API.